# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from .streaming_generation_request import StreamingGenerationRequest


class ContextfulGenerationRequest(StreamingGenerationRequest):
    """
    Examples
    --------
    {
        "context_id": "abc",
        "transcript": "Hello, World!",
        "voice": {"id": "samantha"},
    }
    """

    context_id: str = pydantic.Field()
    """
    Use different context IDs for different generations over one WebSocket connection.
    """

    continue_: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="continue")] = pydantic.Field(
        default=None
    )
    """
    Set to `true` for smooth prosody if text is streamed in chunks and this is not the last chunk.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from .generation_request import GenerationRequest
from .output_format import OutputFormat


class BytesGenerationRequest(GenerationRequest):
    """
    Examples
    --------
    {"transcript": "Hello, World!", "voice": {"id": "samantha"}}
    """

    output_format: typing.Optional[OutputFormat] = pydantic.Field(default=None)
    """
    Audio format specification.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class Response_Chunk(UniversalBaseModel):
    """
    Examples
    --------
    {"context_id": "abc", "data": "base64", "type": "chunk"}
    """

    type: typing.Literal["chunk"] = "chunk"
    context_id: str
    data: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class Response_Done(UniversalBaseModel):
    """
    Examples
    --------
    {"context_id": "abc", "data": "base64", "type": "chunk"}
    """

    type: typing.Literal["done"] = "done"
    context_id: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class Response_Error(UniversalBaseModel):
    """
    Examples
    --------
    {"context_id": "abc", "data": "base64", "type": "chunk"}
    """

    type: typing.Literal["error"] = "error"
    error: str
    status_code: int
    context_id: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


"""
{"context_id": "abc", "data": "base64", "type": "chunk"}
"""
Response = typing.Union[Response_Chunk, Response_Done, Response_Error]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...voices.requests.sampling_params import SamplingParamsParams


class VoiceParams(typing_extensions.TypedDict):
    id: str
    sampling_params: typing_extensions.NotRequired[SamplingParamsParams]
    """
    Optional sampling params overrides. The defaults for this voice can be obtained through the [Voices](../voices/list) endpoint.
    """



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .bytes_generation_request import BytesGenerationRequestParams
from .cancellation_request import CancellationRequestParams
from .chunk import ChunkParams
from .contextful_chunk import ContextfulChunkParams
from .contextful_generation_request import ContextfulGenerationRequestParams
from .done import DoneParams
from .generation_request import GenerationRequestParams
from .output_format import OutputFormatParams
from .response import ResponseParams, Response_ChunkParams, Response_DoneParams, Response_ErrorParams
from .server_sent_event import ServerSentEventParams, ServerSentEvent_ChunkParams, ServerSentEvent_ErrorParams
from .streaming_error import StreamingErrorParams
from .streaming_generation_request import StreamingGenerationRequestParams
from .streaming_output_format import StreamingOutputFormatParams
from .voice import VoiceParams

__all__ = [
    "BytesGenerationRequestParams",
    "CancellationRequestParams",
    "ChunkParams",
    "ContextfulChunkParams",
    "ContextfulGenerationRequestParams",
    "DoneParams",
    "GenerationRequestParams",
    "OutputFormatParams",
    "ResponseParams",
    "Response_ChunkParams",
    "Response_DoneParams",
    "Response_ErrorParams",
    "ServerSentEventParams",
    "ServerSentEvent_ChunkParams",
    "ServerSentEvent_ErrorParams",
    "StreamingErrorParams",
    "StreamingGenerationRequestParams",
    "StreamingOutputFormatParams",
    "VoiceParams",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...voices.types.sampling_params import SamplingParams


class Voice(UniversalBaseModel):
    """
    Examples
    --------
    {"id": "samantha"}
    """

    id: str
    sampling_params: typing.Optional[SamplingParams] = pydantic.Field(default=None)
    """
    Optional sampling params overrides. The defaults for this voice can be obtained through the [Voices](../voices/list) endpoint.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    BytesGenerationRequest,
    CancellationRequest,
    Chunk,
    ContextfulChunk,
    ContextfulGenerationRequest,
    Done,
    GenerationRequest,
    OutputFormat,
    Response,
    Response_Chunk,
    Response_Done,
    Response_Error,
    ServerSentEvent,
    ServerSentEvent_Chunk,
    ServerSentEvent_Error,
    StreamingEncoding,
    StreamingError,
    StreamingGenerationRequest,
    StreamingOutputFormat,
    Voice,
)
from .requests import (
    BytesGenerationRequestParams,
    CancellationRequestParams,
    ChunkParams,
    ContextfulChunkParams,
    ContextfulGenerationRequestParams,
    DoneParams,
    GenerationRequestParams,
    OutputFormatParams,
    ResponseParams,
    Response_ChunkParams,
    Response_DoneParams,
    Response_ErrorParams,
    ServerSentEventParams,
    ServerSentEvent_ChunkParams,
    ServerSentEvent_ErrorParams,
    StreamingErrorParams,
    StreamingGenerationRequestParams,
    StreamingOutputFormatParams,
    VoiceParams,
)

__all__ = [
    "BytesGenerationRequest",
    "BytesGenerationRequestParams",
    "CancellationRequest",
    "CancellationRequestParams",
    "Chunk",
    "ChunkParams",
    "ContextfulChunk",
    "ContextfulChunkParams",
    "ContextfulGenerationRequest",
    "ContextfulGenerationRequestParams",
    "Done",
    "DoneParams",
    "GenerationRequest",
    "GenerationRequestParams",
    "OutputFormat",
    "OutputFormatParams",
    "Response",
    "ResponseParams",
    "Response_Chunk",
    "Response_ChunkParams",
    "Response_Done",
    "Response_DoneParams",
    "Response_Error",
    "Response_ErrorParams",
    "ServerSentEvent",
    "ServerSentEventParams",
    "ServerSentEvent_Chunk",
    "ServerSentEvent_ChunkParams",
    "ServerSentEvent_Error",
    "ServerSentEvent_ErrorParams",
    "StreamingEncoding",
    "StreamingError",
    "StreamingErrorParams",
    "StreamingGenerationRequest",
    "StreamingGenerationRequestParams",
    "StreamingOutputFormat",
    "StreamingOutputFormatParams",
    "Voice",
    "VoiceParams",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from .raw_client import AsyncRawVoicesClient, RawVoicesClient
from .types.voice import Voice


class VoicesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawVoicesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawVoicesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawVoicesClient
        """
        return self._raw_client

    def list(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.List[Voice]:
        """
        List of available voices with IDs and metadata.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[Voice]

        Examples
        --------
        from respeecher import Respeecher

        client = Respeecher(
            api_key="YOUR_API_KEY",
        )
        client.voices.list()
        """
        _response = self._raw_client.list(request_options=request_options)
        return _response.data


class AsyncVoicesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawVoicesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawVoicesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawVoicesClient
        """
        return self._raw_client

    async def list(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.List[Voice]:
        """
        List of available voices with IDs and metadata.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[Voice]

        Examples
        --------
        import asyncio

        from respeecher import AsyncRespeecher

        client = AsyncRespeecher(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.voices.list()


        asyncio.run(main())
        """
        _response = await self._raw_client.list(request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class DoneParams(typing_extensions.TypedDict):
    context_id: str
    """
    ID of the context that has finished generating audio.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class CancellationRequestParams(typing_extensions.TypedDict):
    context_id: str
    """
    Use different context IDs for different generations over one WebSocket connection.
    """

    cancel: typing.Literal[True]



# This file was auto-generated by Fern from our API Definition.

import contextlib
import json
import typing
from contextlib import asynccontextmanager, contextmanager
from json.decoder import JSONDecodeError

import websockets
import websockets.sync.client as websockets_sync_client
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..core.serialization import convert_and_respect_annotation_metadata
from .requests.output_format import OutputFormatParams
from .requests.streaming_output_format import StreamingOutputFormatParams
from .requests.voice import VoiceParams
from .socket_client import AsyncTtsSocketClient, TtsSocketClient
from .types.server_sent_event import ServerSentEvent

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawTtsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    @contextlib.contextmanager
    def bytes(
        self,
        *,
        transcript: str,
        voice: VoiceParams,
        output_format: typing.Optional[OutputFormatParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[HttpResponse[typing.Iterator[bytes]]]:
        """
        The easiest way to generate text-to-speech audio. Not suitable for latency-sensitive applications.

        Parameters
        ----------
        transcript : str
            Text for narration.

        voice : VoiceParams
            Voice for narration.

        output_format : typing.Optional[OutputFormatParams]
            Audio format specification.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.Iterator[HttpResponse[typing.Iterator[bytes]]]
            WAV file (16-bit LE PCM).
        """
        with self._client_wrapper.httpx_client.stream(
            "tts/bytes",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "output_format": convert_and_respect_annotation_metadata(
                    object_=output_format, annotation=OutputFormatParams, direction="write"
                ),
                "transcript": transcript,
                "voice": convert_and_respect_annotation_metadata(
                    object_=voice, annotation=VoiceParams, direction="write"
                ),
            },
            request_options=request_options,
            omit=OMIT,
        ) as _response:

            def _stream() -> HttpResponse[typing.Iterator[bytes]]:
                try:
                    if 200 <= _response.status_code < 300:
                        _chunk_size = request_options.get("chunk_size", None) if request_options is not None else None
                        return HttpResponse(
                            response=_response, data=(_chunk for _chunk in _response.iter_bytes(chunk_size=_chunk_size))
                        )
                    _response.read()
                    _response_json = _response.json()
                except JSONDecodeError:
                    raise ApiError(
                        status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
                    )
                raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

            yield _stream()

    @contextlib.contextmanager
    def sse(
        self,
        *,
        transcript: str,
        voice: VoiceParams,
        output_format: typing.Optional[StreamingOutputFormatParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[HttpResponse[typing.Iterator[ServerSentEvent]]]:
        """
        Stream text-to-speech audio as JSONL (JSON lines) objects over HTTP. A less performant alternative to WebSockets, without text input streaming.

        Parameters
        ----------
        transcript : str
            Text for narration.

        voice : VoiceParams
            Voice for narration.

        output_format : typing.Optional[StreamingOutputFormatParams]
            Audio format specification.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Yields
        ------
        typing.Iterator[HttpResponse[typing.Iterator[ServerSentEvent]]]
        """
        with self._client_wrapper.httpx_client.stream(
            "tts/sse",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "output_format": convert_and_respect_annotation_metadata(
                    object_=output_format, annotation=StreamingOutputFormatParams, direction="write"
                ),
                "transcript": transcript,
                "voice": convert_and_respect_annotation_metadata(
                    object_=voice, annotation=VoiceParams, direction="write"
                ),
            },
            request_options=request_options,
            omit=OMIT,
        ) as _response:

            def _stream() -> HttpResponse[typing.Iterator[ServerSentEvent]]:
                try:
                    if 200 <= _response.status_code < 300:

                        def _iter():
                            for _text in _response.iter_lines():
                                try:
                                    if len(_text) == 0:
                                        continue
                                    yield typing.cast(
                                        ServerSentEvent,
                                        parse_obj_as(
                                            type_=ServerSentEvent,  # type: ignore
                                            object_=json.loads(_text),
                                        ),
                                    )
                                except Exception:
                                    pass
                            return

                        return HttpResponse(response=_response, data=_iter())
                    _response.read()
                    _response_json = _response.json()
                except JSONDecodeError:
                    raise ApiError(
                        status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
                    )
                raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

            yield _stream()

    @contextmanager
    def connect(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.Iterator[TtsSocketClient]:
        """
        A single connection for multiple concurrent text-to-speech generations, with input and output streaming. Provides the best latency and performance out of the text-to-speech endpoints.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TtsSocketClient
        """
        ws_url = self._client_wrapper.get_environment().ws + "/tts/websocket"
        headers = self._client_wrapper.get_headers()
        if request_options and "additional_headers" in request_options:
            headers.update(request_options["additional_headers"])
        try:
            with websockets_sync_client.connect(ws_url, additional_headers=headers) as protocol:
                yield TtsSocketClient(websocket=protocol)
        except websockets.exceptions.InvalidStatusCode as exc:
            status_code: int = exc.status_code
            if status_code == 401:
                raise ApiError(
                    status_code=status_code,
                    headers=dict(headers),
                    body="Websocket initialized with invalid credentials.",
                )
            raise ApiError(
                status_code=status_code,
                headers=dict(headers),
                body="Unexpected error when initializing websocket connection.",
            )


class AsyncRawTtsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    @contextlib.asynccontextmanager
    async def bytes(
        self,
        *,
        transcript: str,
        voice: VoiceParams,
        output_format: typing.Optional[OutputFormatParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[AsyncHttpResponse[typing.AsyncIterator[bytes]]]:
        """
        The easiest way to generate text-to-speech audio. Not suitable for latency-sensitive applications.

        Parameters
        ----------
        transcript : str
            Text for narration.

        voice : VoiceParams
            Voice for narration.

        output_format : typing.Optional[OutputFormatParams]
            Audio format specification.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.AsyncIterator[AsyncHttpResponse[typing.AsyncIterator[bytes]]]
            WAV file (16-bit LE PCM).
        """
        async with self._client_wrapper.httpx_client.stream(
            "tts/bytes",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "output_format": convert_and_respect_annotation_metadata(
                    object_=output_format, annotation=OutputFormatParams, direction="write"
                ),
                "transcript": transcript,
                "voice": convert_and_respect_annotation_metadata(
                    object_=voice, annotation=VoiceParams, direction="write"
                ),
            },
            request_options=request_options,
            omit=OMIT,
        ) as _response:

            async def _stream() -> AsyncHttpResponse[typing.AsyncIterator[bytes]]:
                try:
                    if 200 <= _response.status_code < 300:
                        _chunk_size = request_options.get("chunk_size", None) if request_options is not None else None
                        return AsyncHttpResponse(
                            response=_response,
                            data=(_chunk async for _chunk in _response.aiter_bytes(chunk_size=_chunk_size)),
                        )
                    await _response.aread()
                    _response_json = _response.json()
                except JSONDecodeError:
                    raise ApiError(
                        status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
                    )
                raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

            yield await _stream()

    @contextlib.asynccontextmanager
    async def sse(
        self,
        *,
        transcript: str,
        voice: VoiceParams,
        output_format: typing.Optional[StreamingOutputFormatParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[AsyncHttpResponse[typing.AsyncIterator[ServerSentEvent]]]:
        """
        Stream text-to-speech audio as JSONL (JSON lines) objects over HTTP. A less performant alternative to WebSockets, without text input streaming.

        Parameters
        ----------
        transcript : str
            Text for narration.

        voice : VoiceParams
            Voice for narration.

        output_format : typing.Optional[StreamingOutputFormatParams]
            Audio format specification.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Yields
        ------
        typing.AsyncIterator[AsyncHttpResponse[typing.AsyncIterator[ServerSentEvent]]]
        """
        async with self._client_wrapper.httpx_client.stream(
            "tts/sse",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "output_format": convert_and_respect_annotation_metadata(
                    object_=output_format, annotation=StreamingOutputFormatParams, direction="write"
                ),
                "transcript": transcript,
                "voice": convert_and_respect_annotation_metadata(
                    object_=voice, annotation=VoiceParams, direction="write"
                ),
            },
            request_options=request_options,
            omit=OMIT,
        ) as _response:

            async def _stream() -> AsyncHttpResponse[typing.AsyncIterator[ServerSentEvent]]:
                try:
                    if 200 <= _response.status_code < 300:

                        async def _iter():
                            async for _text in _response.aiter_lines():
                                try:
                                    if len(_text) == 0:
                                        continue
                                    yield typing.cast(
                                        ServerSentEvent,
                                        parse_obj_as(
                                            type_=ServerSentEvent,  # type: ignore
                                            object_=json.loads(_text),
                                        ),
                                    )
                                except Exception:
                                    pass
                            return

                        return AsyncHttpResponse(response=_response, data=_iter())
                    await _response.aread()
                    _response_json = _response.json()
                except JSONDecodeError:
                    raise ApiError(
                        status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
                    )
                raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

            yield await _stream()

    @asynccontextmanager
    async def connect(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.AsyncIterator[AsyncTtsSocketClient]:
        """
        A single connection for multiple concurrent text-to-speech generations, with input and output streaming. Provides the best latency and performance out of the text-to-speech endpoints.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncTtsSocketClient
        """
        ws_url = self._client_wrapper.get_environment().ws + "/tts/websocket"
        headers = self._client_wrapper.get_headers()
        if request_options and "additional_headers" in request_options:
            headers.update(request_options["additional_headers"])
        try:
            async with websockets.connect(ws_url, extra_headers=headers) as protocol:
                yield AsyncTtsSocketClient(websocket=protocol)
        except websockets.exceptions.InvalidStatusCode as exc:
            status_code: int = exc.status_code
            if status_code == 401:
                raise ApiError(
                    status_code=status_code,
                    headers=dict(headers),
                    body="Websocket initialized with invalid credentials.",
                )
            raise ApiError(
                status_code=status_code,
                headers=dict(headers),
                body="Unexpected error when initializing websocket connection.",
            )



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class SamplingParamsParams(typing_extensions.TypedDict):
    seed: typing_extensions.NotRequired[int]
    """
    Generations with the same parameters _including_ a non-null `seed` are identical.
    """

    temperature: typing_extensions.NotRequired[float]
    """
    Smaller values correspond to more stable but less expressive speech. Must be greater than or equal to 0.
    """

    top_k: typing_extensions.NotRequired[int]
    """
    Must be -1 or greater than 0.
    """

    top_p: typing_extensions.NotRequired[float]
    """
    Must be greater than 0 and less than or equal to 1.
    """

    min_p: typing_extensions.NotRequired[float]
    """
    Must be between 0 and 1, inclusive.
    """

    presence_penalty: typing_extensions.NotRequired[float]
    """
    Must be between 0 and 2, inclusive.
    """

    repetition_penalty: typing_extensions.NotRequired[float]
    """
    Must be between 1 and 2, inclusive.
    """

    frequency_penalty: typing_extensions.NotRequired[float]
    """
    Must be between 0 and 2, inclusive.
    """



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .generation_request import GenerationRequestParams
from .streaming_output_format import StreamingOutputFormatParams


class StreamingGenerationRequestParams(GenerationRequestParams):
    output_format: typing_extensions.NotRequired[StreamingOutputFormatParams]
    """
    Audio format specification.
    """



# This file was auto-generated by Fern from our API Definition.

import os
import typing

import httpx
from .core.api_error import ApiError
from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .environment import RespeecherEnvironment
from .tts.client import AsyncTtsClient, TtsClient
from .voices.client import AsyncVoicesClient, VoicesClient


class Respeecher:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    environment : RespeecherEnvironment
        The environment to use for requests from the client. from .environment import RespeecherEnvironment



        Defaults to RespeecherEnvironment.PUBLIC_EN_RT



    api_key : typing.Optional[str]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from respeecher import Respeecher

    client = Respeecher(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        environment: RespeecherEnvironment = RespeecherEnvironment.PUBLIC_EN_RT,
        api_key: typing.Optional[str] = os.getenv("RESPEECHER_API_KEY"),
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        if api_key is None:
            raise ApiError(
                body="The client must be instantiated be either passing in api_key or setting RESPEECHER_API_KEY"
            )
        self._client_wrapper = SyncClientWrapper(
            environment=environment,
            api_key=api_key,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.tts = TtsClient(client_wrapper=self._client_wrapper)
        self.voices = VoicesClient(client_wrapper=self._client_wrapper)


class AsyncRespeecher:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    environment : RespeecherEnvironment
        The environment to use for requests from the client. from .environment import RespeecherEnvironment



        Defaults to RespeecherEnvironment.PUBLIC_EN_RT



    api_key : typing.Optional[str]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from respeecher import AsyncRespeecher

    client = AsyncRespeecher(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        environment: RespeecherEnvironment = RespeecherEnvironment.PUBLIC_EN_RT,
        api_key: typing.Optional[str] = os.getenv("RESPEECHER_API_KEY"),
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        if api_key is None:
            raise ApiError(
                body="The client must be instantiated be either passing in api_key or setting RESPEECHER_API_KEY"
            )
        self._client_wrapper = AsyncClientWrapper(
            environment=environment,
            api_key=api_key,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.tts = AsyncTtsClient(client_wrapper=self._client_wrapper)
        self.voices = AsyncVoicesClient(client_wrapper=self._client_wrapper)



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .voice import VoiceParams


class GenerationRequestParams(typing_extensions.TypedDict):
    transcript: str
    """
    Text for narration.
    """

    voice: VoiceParams
    """
    Voice for narration.
    """
